pilas.fps.FPS

Package pilas :: Module fps :: Class FPS |
[hide private]
[frames] | no frames]

# Class FPS

source code

    object --+
             |
            FPS

Representa un controlador de tiempo para el mainloop de pilas.

Instance Methods | [hide private]
__init__(self, fps, usar_modo_economico) Inicia el administrador de cuadros por segundo. | source code
actualizar(self) | source code
_procesar_fps(self, actual) | source code
obtener_cuadros_por_segundo(self) Retorna la cantidad de cuadros por segundo. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, fps, usar_modo_economico) (Constructor) | source code
Inicia el administrador de cuadros por segundo. :param fps: Cantidad de cuadros por segundo esperados. :param usar_modo_economico: Si vale True intenta reducir la cantidad de recursos utilizados. Overrides: object.__init__